@@ -28,7 +28,6 @@ class Assignments(BrowserView):
         groups = self.getGroups()
         return str([group['id'] for group in groups])
 
-
     def getGroups(self): 
         """ Return PAS groups """
         search_view = self.context.restrictedTraverse('@@pas_search')
@@ -42,7 +41,6 @@ class Assignments(BrowserView):
         result = sorted(result, key=operator.itemgetter('title')) 
         return result
 
-
     def _get_memberids_from_request(self):
         """ Return a list of userids based on the 'group' and 'userid'
             parameters from the request.
@@ -116,6 +114,34 @@ class Assignments(BrowserView):
         return self.request.response.redirect(self.context.absolute_url())
 
 
+    def remove_assignments(self):
+        """ Remove a list of portlets from user dashboards """
+
+        site = getUtility(ISiteRoot)
+        for id in self.request.form.get('ids', []):
+            # id = 'user=XXXX::manager=YYYY:portlet=ZZZZ'
+            items = id.split('::')
+            userid = items[0].split('=')[-1]
+            portlet_manager_name = items[1].split('=')[-1]
+            portlet_id = items[2].split('=')[-1]
+
+            # get hold of the user dashboard manager
+            portlet_manager = getUtility(IPortletManager, name=portlet_manager_name)
+            mapping = assignment_mapping_from_key(site, 
+                                                  portlet_manager_name,
+                                                  category='user', 
+                                                  key=userid, 
+                                                  create=False)
+            del mapping[portlet_id]
+            mapping._p_changed = True
+
+        self.context.plone_utils.addPortalMessage(_(u'label_portlets_removed_from_dashboard',
+                                                    u'Portlets removed from user dashboard(s)'))
+
+        url = '%s/@@view-assignments?userid=%s&group=%s' % (self.context.absolute_url(),
+                self.request.get('userid', ''), self.request.get('group', ''))
+        return self.request.response.redirect(url)
+
     def __call__(self, *args, **kw):
         return self.template(*args, **kw)
 
@@ -134,6 +160,7 @@ class ViewAssignments(Assignments):
         for userid in userids:
             # iterate over the four portlet managers in each user dashboard
             dash2portlets = list()
+            found = False
             for i in range(1, 5):
                 # get hold of the user dashboard manager
                 manager_name = 'plone.dashboard%d' % i
@@ -145,11 +172,14 @@ class ViewAssignments(Assignments):
                                                       create=True)
                 portlets = list()
                 for portlet_id in mapping:
-                    portlets.append(dict(portlet_id=portlet_id, assignment=mapping[portlet_id]))
+                    assignment = mapping[portlet_id]
+                    parameters = dict([(k,v) for k,v in assignment.__dict__.items() if not k.startswith('_')])
+                    portlets.append(dict(portlet_id=portlet_id, 
+                                         assignment=assignment,
+                                         parameters=parameters))
+                    found = True
 
                 dash2portlets.append(dict(manager=manager_name, portlets=portlets))
-            user2dash.append(dict(userid=userid, dashboards=dash2portlets))
+            user2dash.append(dict(userid=userid, dashboards=dash2portlets, hasDashboard=found))
 
         return user2dash
-
-
